==============================
Models instruments
==============================

Instrument
-----------

.. autoclass:: exorad.models.instruments.Instrument
    :members:
    :undoc-members:
    :show-inheritance:

Photometer
-----------

.. autoclass:: exorad.models.instruments.Photometer
    :members:
    :undoc-members:
    :show-inheritance:

Spectrometer
------------

.. autoclass:: exorad.models.instruments.Spectrometer
    :members:
    :undoc-members:
    :show-inheritance:
